<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Tourable Pro
 * @since Tourable Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'tourable_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','tourable-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'tourable-pro' ),
	'panel'             => 'tourable_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'tourable_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Tourable_Pro_Switch_Control( $wp_customize, 'tourable_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'on_off_label' 		=> tourable_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_blog_section',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[blog_title]', array(
		'selector'            => '#latest-posts .section-header h2.section-title',
		'settings'            => 'tourable_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_blog_title_partial',
    ) );
}

// blog subtitle setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_blog_section',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[blog_sub_title]', array(
		'selector'            => '#latest-posts .latest-content p',
		'settings'            => 'tourable_pro_theme_options[blog_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_blog_sub_title_partial',
    ) );
}

// blog title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_read_more]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_read_more'],
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_blog_section',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Blog content type control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'tourable_pro_sanitize_select',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'choices'			=> tourable_pro_blog_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'tourable_pro_sanitize_number_range',
	'validate_callback' => 'tourable_pro_validate_blog_count',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'tourable-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'active_callback'   => 'tourable_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'tourable_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_blog_section',
		'choices'			=> tourable_pro_page_choices(),
		'active_callback'	=> 'tourable_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'tourable_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_blog_section',
		'choices'			=> tourable_pro_post_choices(),
		'active_callback'	=> 'tourable_pro_is_blog_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'tourable_pro_theme_options[blog_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'tourable_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Tourable_Pro_Dropdown_Chooser( $wp_customize, 'tourable_pro_theme_options[blog_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'tourable-pro' ), $i ),
		'section'           => 'tourable_pro_blog_section',
		'choices'			=> tourable_pro_trip_choices(),
		'active_callback'	=> 'tourable_pro_is_blog_section_content_trip_enable',
	) ) );


endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'tourable_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'tourable-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'tourable_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Category_Control( $wp_customize,'tourable_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'tourable-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'tourable_pro_is_blog_section_content_recent_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[blog_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[blog_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_blog_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[blog_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[blog_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_blog_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'tourable_pro_theme_options[blog_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Tourable_Pro_Dropdown_Taxonomies_Control( $wp_customize,'tourable_pro_theme_options[blog_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'tourable-pro' ),
	'section'           => 'tourable_pro_blog_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'tourable_pro_is_blog_section_content_destination_enable'
) ) );

// blog btn title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_btn_title'],
	'transport'			=> 'postMessage',
) );



$wp_customize->add_control( 'tourable_pro_theme_options[blog_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_blog_section',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'tourable_pro_theme_options[blog_btn_title]', array(
		'selector'            => '#latest-posts .read-more a.btn',
		'settings'            => 'tourable_pro_theme_options[blog_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'tourable_pro_blog_btn_title_partial',
    ) );
}

// blog btn title setting and control
$wp_customize->add_setting( 'tourable_pro_theme_options[blog_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'tourable_pro_theme_options[blog_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'tourable-pro' ),
	'section'        	=> 'tourable_pro_blog_section',
	'active_callback' 	=> 'tourable_pro_is_blog_section_enable',
	'type'				=> 'url',
) );